@@ -15,15 +15,26 @@ extern "C" {
 #include "call/vec2.h"
 #include "call/vec3.h"
 #include "call/vec4.h"
+#include "call/ivec2.h"
+#include "call/ivec3.h"
+#include "call/ivec4.h"
 #include "call/mat2.h"
+#include "call/mat2x3.h"
+#include "call/mat2x4.h"
 #include "call/mat3.h"
+#include "call/mat3x2.h"
+#include "call/mat3x4.h"
 #include "call/mat4.h"
+#include "call/mat4x2.h"
+#include "call/mat4x3.h"
 #include "call/affine.h"
 #include "call/cam.h"
 #include "call/quat.h"
 #include "call/euler.h"
 #include "call/plane.h"
+#include "call/noise.h"
 #include "call/frustum.h"
+#include "call/aabb2d.h"
 #include "call/box.h"
 #include "call/io.h"
 #include "call/project.h"
