@@ -82,7 +82,7 @@ glmc_mat3_rmc(vec3 r, mat3 m, vec3 c);
 
 CGLM_EXPORT
 void
-glmc_mat3_make(float * __restrict src, mat3 dest);
+glmc_mat3_make(const float * __restrict src, mat3 dest);
 
 #ifdef __cplusplus
 }
