@@ -14,8 +14,8 @@
    CGLM_INLINE void glm_mat2x3_copy(mat2x3 mat, mat2x3 dest);
    CGLM_INLINE void glm_mat2x3_zero(mat2x3 mat);
    CGLM_INLINE void glm_mat2x3_make(const float * __restrict src, mat2x3 dest);
-   CGLM_INLINE void glm_mat2x3_mul(mat2x3 m1, mat3x2 m2, mat2 dest);
-   CGLM_INLINE void glm_mat2x3_mulv(mat2x3 m, vec3 v, vec2 dest);
+   CGLM_INLINE void glm_mat2x3_mul(mat2x3 m1, mat3x2 m2, mat3 dest);
+   CGLM_INLINE void glm_mat2x3_mulv(mat2x3 m, vec2 v, vec3 dest);
    CGLM_INLINE void glm_mat2x3_transpose(mat2x3 m, mat3x2 dest);
    CGLM_INLINE void glm_mat2x3_scale(mat2x3 m, float s);
  */
@@ -82,7 +82,7 @@ glm_mat2x3_make(const float * __restrict src, mat2x3 dest) {
  * @brief multiply m1 and m2 to dest
  *
  * @code
- * glm_mat2x3_mul(mat2x3, mat3x2, mat2);
+ * glm_mat2x3_mul(mat2x3, mat3x2, mat3);
  * @endcode
  *
  * @param[in]  m1   left matrix (mat2x3)
@@ -91,19 +91,25 @@ glm_mat2x3_make(const float * __restrict src, mat2x3 dest) {
  */
 CGLM_INLINE
 void
-glm_mat2x3_mul(mat2x3 m1, mat3x2 m2, mat2 dest) {
-  float a00 = m1[0][0], a01 = m1[0][1], a02 = m1[0][2],
+glm_mat2x3_mul(mat2x3 m1, mat3x2 m2, mat3 dest) {
+  float a00 = m1[0][0], a01 = m1[0][1], a02 = m1[0][2], 
         a10 = m1[1][0], a11 = m1[1][1], a12 = m1[1][2],
 
         b00 = m2[0][0], b01 = m2[0][1],
         b10 = m2[1][0], b11 = m2[1][1],
         b20 = m2[2][0], b21 = m2[2][1];
 
-  dest[0][0] = a00 * b00 + a01 * b10 + a02 * b20;
-  dest[0][1] = a00 * b01 + a01 * b11 + a02 * b21;
+  dest[0][0] = a00 * b00 + a10 * b01;
+  dest[0][1] = a01 * b00 + a11 * b01;
+  dest[0][2] = a02 * b00 + a12 * b01;
 
-  dest[1][0] = a10 * b00 + a11 * b10 + a12 * b20;
-  dest[1][1] = a10 * b01 + a11 * b11 + a12 * b21;
+  dest[1][0] = a00 * b10 + a10 * b11;
+  dest[1][1] = a01 * b10 + a11 * b11;
+  dest[1][2] = a02 * b10 + a12 * b11;
+
+  dest[2][0] = a00 * b20 + a10 * b21;
+  dest[2][1] = a01 * b20 + a11 * b21;
+  dest[2][2] = a02 * b20 + a12 * b21;
 }
 
 /*!
@@ -115,11 +121,12 @@ glm_mat2x3_mul(mat2x3 m1, mat3x2 m2, mat2 dest) {
  */
 CGLM_INLINE
 void
-glm_mat2x3_mulv(mat2x3 m, vec3 v, vec2 dest) {
-  float v0 = v[0], v1 = v[1], v2 = v[2];
+glm_mat2x3_mulv(mat2x3 m, vec2 v, vec3 dest) {
+  float v0 = v[0], v1 = v[1];
 
-  dest[0] = m[0][0] * v0 + m[0][1] * v1 + m[0][2] * v2;
-  dest[1] = m[1][0] * v0 + m[1][1] * v1 + m[1][2] * v2;
+  dest[0] = m[0][0] * v0 + m[1][0] * v1;
+  dest[1] = m[0][1] * v0 + m[1][1] * v1;
+  dest[2] = m[0][2] * v0 + m[1][2] * v1;
 }
 
 /*!
