@@ -14,8 +14,8 @@
    CGLM_INLINE void glm_mat4x3_copy(mat4x3 mat, mat4x3 dest);
    CGLM_INLINE void glm_mat4x3_zero(mat4x3 mat);
    CGLM_INLINE void glm_mat4x3_make(const float * __restrict src, mat4x3 dest);
-   CGLM_INLINE void glm_mat4x3_mul(mat4x3 m1, mat3x4 m2, mat4 dest);
-   CGLM_INLINE void glm_mat4x3_mulv(mat4x3 m, vec3 v, vec4 dest);
+   CGLM_INLINE void glm_mat4x3_mul(mat4x3 m1, mat3x4 m2, mat3 dest);
+   CGLM_INLINE void glm_mat4x3_mulv(mat4x3 m, vec4 v, vec3 dest);
    CGLM_INLINE void glm_mat4x3_transpose(mat4x3 m, mat3x4 dest);
    CGLM_INLINE void glm_mat4x3_scale(mat4x3 m, float s);
  */
@@ -99,16 +99,16 @@ glm_mat4x3_make(const float * __restrict src, mat4x3 dest) {
  * @brief multiply m1 and m2 to dest
  *
  * @code
- * glm_mat4x3_mul(mat4x3, mat3x4, mat4);
+ * glm_mat4x3_mul(mat4x3, mat3x4, mat3);
  * @endcode
  *
  * @param[in]  m1   left matrix (mat4x3)
  * @param[in]  m2   right matrix (mat3x4)
- * @param[out] dest destination matrix (mat4)
+ * @param[out] dest destination matrix (mat3)
  */
 CGLM_INLINE
 void
-glm_mat4x3_mul(mat4x3 m1, mat3x4 m2, mat4 dest) {
+glm_mat4x3_mul(mat4x3 m1, mat3x4 m2, mat3 dest) {
   float a00 = m1[0][0], a01 = m1[0][1], a02 = m1[0][2],
         a10 = m1[1][0], a11 = m1[1][1], a12 = m1[1][2],
         a20 = m1[2][0], a21 = m1[2][1], a22 = m1[2][2],
@@ -118,29 +118,21 @@ glm_mat4x3_mul(mat4x3 m1, mat3x4 m2, mat4 dest) {
         b10 = m2[1][0], b11 = m2[1][1], b12 = m2[1][2], b13 = m2[1][3],
         b20 = m2[2][0], b21 = m2[2][1], b22 = m2[2][2], b23 = m2[2][3];
 
-  dest[0][0] = a00 * b00 + a01 * b10 + a02 * b20;
-  dest[0][1] = a00 * b01 + a01 * b11 + a02 * b21;
-  dest[0][2] = a00 * b02 + a01 * b12 + a02 * b22;
-  dest[0][3] = a00 * b03 + a01 * b13 + a02 * b23;
+  dest[0][0] = a00 * b00 + a10 * b01 + a20 * b02 + a30 * b03;
+  dest[0][1] = a01 * b00 + a11 * b01 + a21 * b02 + a31 * b03;
+  dest[0][2] = a02 * b00 + a12 * b01 + a22 * b02 + a32 * b03;
 
-  dest[1][0] = a10 * b00 + a11 * b10 + a12 * b20;
-  dest[1][1] = a10 * b01 + a11 * b11 + a12 * b21;
-  dest[1][2] = a10 * b02 + a11 * b12 + a12 * b22;
-  dest[1][3] = a10 * b03 + a11 * b13 + a12 * b23;
+  dest[1][0] = a00 * b10 + a10 * b11 + a20 * b12 + a30 * b13;
+  dest[1][1] = a01 * b10 + a11 * b11 + a21 * b12 + a31 * b13;
+  dest[1][2] = a02 * b10 + a12 * b11 + a22 * b12 + a32 * b13;
 
-  dest[2][0] = a20 * b00 + a21 * b10 + a22 * b20;
-  dest[2][1] = a20 * b01 + a21 * b11 + a22 * b21;
-  dest[2][2] = a20 * b02 + a21 * b12 + a22 * b22;
-  dest[2][3] = a20 * b03 + a21 * b13 + a22 * b23;
-
-  dest[3][0] = a30 * b00 + a31 * b10 + a32 * b20;
-  dest[3][1] = a30 * b01 + a31 * b11 + a32 * b21;
-  dest[3][2] = a30 * b02 + a31 * b12 + a32 * b22;
-  dest[3][3] = a30 * b03 + a31 * b13 + a32 * b23;
+  dest[2][0] = a00 * b20 + a10 * b21 + a20 * b22 + a30 * b23;
+  dest[2][1] = a01 * b20 + a11 * b21 + a21 * b22 + a31 * b23;
+  dest[2][2] = a02 * b20 + a12 * b21 + a22 * b22 + a32 * b23;
 }
 
 /*!
- * @brief multiply matrix with column vector and store in dest vector
+ * @brief multiply matrix with column vector and store in dest column vector
  *
  * @param[in]  m    matrix (left)
  * @param[in]  v    vector (right, column vector)
@@ -148,13 +140,12 @@ glm_mat4x3_mul(mat4x3 m1, mat3x4 m2, mat4 dest) {
  */
 CGLM_INLINE
 void
-glm_mat4x3_mulv(mat4x3 m, vec3 v, vec4 dest) {
-  float v0 = v[0], v1 = v[1], v2 = v[2];
+glm_mat4x3_mulv(mat4x3 m, vec4 v, vec3 dest) {
+  float v0 = v[0], v1 = v[1], v2 = v[2], v3 = v[3];
 
-  dest[0] = m[0][0] * v0 + m[0][1] * v1 + m[0][2] * v2;
-  dest[1] = m[1][0] * v0 + m[1][1] * v1 + m[1][2] * v2;
-  dest[2] = m[2][0] * v0 + m[2][1] * v1 + m[2][2] * v2;
-  dest[3] = m[3][0] * v0 + m[3][1] * v1 + m[3][2] * v2;
+  dest[0] = m[0][0] * v0 + m[1][0] * v1 + m[2][0] * v2 + m[3][0] * v3;
+  dest[1] = m[0][1] * v0 + m[1][1] * v1 + m[2][1] * v2 + m[3][1] * v3;
+  dest[2] = m[0][2] * v0 + m[1][2] * v1 + m[2][2] * v2 + m[3][2] * v3;
 }
 
 /*!
