@@ -16,12 +16,22 @@ extern "C" {
 #include "struct/vec2.h"
 #include "struct/vec3.h"
 #include "struct/vec4.h"
+#include "struct/ivec2.h"
+#include "struct/ivec3.h"
+#include "struct/ivec4.h"
 #include "struct/mat2.h"
+#include "struct/mat2x3.h"
+#include "struct/mat2x4.h"
 #include "struct/mat3.h"
+#include "struct/mat3x2.h"
+#include "struct/mat3x4.h"
 #include "struct/mat4.h"
+#include "struct/mat4x2.h"
+#include "struct/mat4x3.h"
 #include "struct/affine.h"
 #include "struct/frustum.h"
 #include "struct/plane.h"
+#include "struct/noise.h"
 #include "struct/box.h"
 #include "struct/color.h"
 #include "struct/io.h"
@@ -32,6 +42,7 @@ extern "C" {
 #include "struct/sphere.h"
 #include "struct/curve.h"
 #include "struct/affine2d.h"
+#include "struct/ray.h"
 
 #ifdef __cplusplus
 }
