@@ -61,3 +61,39 @@ void
 glmc_euler_by_order(vec3 angles, glm_euler_seq axis, mat4 dest) {
   glm_euler_by_order(angles, axis, dest);
 }
+
+CGLM_EXPORT
+void
+glmc_euler_xyz_quat(vec3 angles, versor dest) {
+  glm_euler_xyz_quat(angles, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_euler_xzy_quat(vec3 angles, versor dest) {
+  glm_euler_xzy_quat(angles, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_euler_yxz_quat(vec3 angles, versor dest) {
+  glm_euler_yxz_quat(angles, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_euler_yzx_quat(vec3 angles, versor dest) {
+  glm_euler_yzx_quat(angles, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_euler_zxy_quat(vec3 angles, versor dest) {
+  glm_euler_zxy_quat(angles, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_euler_zyx_quat(vec3 angles, versor dest) {
+  glm_euler_zyx_quat(angles, dest);
+}
