@@ -26,6 +26,12 @@ glmc_project(vec3 pos, mat4 m, vec4 vp, vec3 dest) {
   glm_project(pos, m, vp, dest);
 }
 
+CGLM_EXPORT
+float
+glmc_project_z(vec3 pos, mat4 m) {
+  return glm_project_z(pos, m);
+}
+
 CGLM_EXPORT
 void
 glmc_pickmatrix(vec2 center, vec2 size, vec4 vp, mat4 dest) {
