@@ -266,12 +266,6 @@ glmc_vec4_lerpc(vec4 from, vec4 to, float t, vec4 dest) {
   glm_vec4_lerpc(from, to, t, dest);
 }
 
-CGLM_EXPORT
-void
-glmc_vec4_step_uni(float edge, vec4 x, vec4 dest) {
-  glm_vec4_step_uni(edge, x, dest);
-}
-
 CGLM_EXPORT
 void
 glmc_vec4_step(vec4 edge, vec4 x, vec4 dest) {
@@ -308,6 +302,12 @@ glmc_vec4_cubic(float s, vec4 dest) {
   glm_vec4_cubic(s, dest);
 }
 
+CGLM_EXPORT
+void
+glmc_vec4_swizzle(vec4 v, int mask, vec4 dest) {
+  glm_vec4_swizzle(v, mask, dest);
+}
+
 /* ext */
 
 CGLM_EXPORT
@@ -406,6 +406,30 @@ glmc_vec4_fract(vec4 v, vec4 dest) {
   glm_vec4_fract(v, dest);
 }
 
+CGLM_EXPORT
+void
+glmc_vec4_floor(vec4 v, vec4 dest) {
+  glm_vec4_floor(v, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_vec4_mods(vec4 v, float s, vec4 dest) {
+  glm_vec4_mods(v, s, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_vec4_steps(float edge, vec4 v, vec4 dest) {
+  glm_vec4_steps(edge, v, dest);
+}
+
+CGLM_EXPORT
+void
+glmc_vec4_stepr(vec4 edge, float v, vec4 dest) {
+  glm_vec4_stepr(edge, v, dest);
+}
+
 CGLM_EXPORT
 float
 glmc_vec4_hadd(vec4 v) {
