@@ -97,6 +97,9 @@ TEST_DECLARE(glmc_rotate2d_make)
 TEST_DECLARE(glmc_rotate2d)
 TEST_DECLARE(glmc_rotate2d_to)
 
+/* aabb2d */
+TEST_DECLARE(glm_aabb2d_sizev)
+
 /* mat4 */
 TEST_DECLARE(glm_mat4_ucopy)
 TEST_DECLARE(glm_mat4_copy)
@@ -356,6 +359,14 @@ TEST_DECLARE(glmc_project)
 TEST_DECLARE(glm_plane_normalize)
 TEST_DECLARE(glmc_plane_normalize)
 
+/* noise */
+TEST_DECLARE(glm_perlin_vec4)
+TEST_DECLARE(glmc_perlin_vec4)
+TEST_DECLARE(glm_perlin_vec3)
+TEST_DECLARE(glmc_perlin_vec3)
+TEST_DECLARE(glm_perlin_vec2)
+TEST_DECLARE(glmc_perlin_vec2)
+
 /* utils */
 TEST_DECLARE(clamp)
 
@@ -531,6 +542,11 @@ TEST_DECLARE(glm_vec2_maxv)
 TEST_DECLARE(glm_vec2_minv)
 TEST_DECLARE(glm_vec2_clamp)
 TEST_DECLARE(glm_vec2_abs)
+TEST_DECLARE(glm_vec2_fract)
+TEST_DECLARE(glm_vec2_floor)
+TEST_DECLARE(glm_vec2_mods)
+TEST_DECLARE(glm_vec2_steps)
+TEST_DECLARE(glm_vec2_stepr)
 TEST_DECLARE(glm_vec2_lerp)
 TEST_DECLARE(glm_vec2_complex_mul)
 TEST_DECLARE(glm_vec2_complex_div)
@@ -579,6 +595,11 @@ TEST_DECLARE(glmc_vec2_maxv)
 TEST_DECLARE(glmc_vec2_minv)
 TEST_DECLARE(glmc_vec2_clamp)
 TEST_DECLARE(glmc_vec2_abs)
+TEST_DECLARE(glmc_vec2_fract)
+TEST_DECLARE(glmc_vec2_floor)
+TEST_DECLARE(glmc_vec2_mods)
+TEST_DECLARE(glmc_vec2_steps)
+TEST_DECLARE(glmc_vec2_stepr)
 TEST_DECLARE(glmc_vec2_lerp)
 TEST_DECLARE(glmc_vec2_complex_mul)
 TEST_DECLARE(glmc_vec2_complex_div)
@@ -662,7 +683,6 @@ TEST_DECLARE(glm_vec3_ortho)
 TEST_DECLARE(glm_vec3_clamp)
 TEST_DECLARE(glm_vec3_mix)
 TEST_DECLARE(glm_vec3_mixc)
-TEST_DECLARE(glm_vec3_step_uni)
 TEST_DECLARE(glm_vec3_step)
 TEST_DECLARE(glm_vec3_smoothstep_uni)
 TEST_DECLARE(glm_vec3_smoothstep)
@@ -684,6 +704,10 @@ TEST_DECLARE(glm_vec3_isvalid)
 TEST_DECLARE(glm_vec3_sign)
 TEST_DECLARE(glm_vec3_abs)
 TEST_DECLARE(glm_vec3_fract)
+TEST_DECLARE(glm_vec3_floor)
+TEST_DECLARE(glm_vec3_mods)
+TEST_DECLARE(glm_vec3_steps)
+TEST_DECLARE(glm_vec3_stepr)
 TEST_DECLARE(glm_vec3_hadd)
 TEST_DECLARE(glm_vec3_sqrt)
 TEST_DECLARE(glm_vec3_make)
@@ -741,7 +765,6 @@ TEST_DECLARE(glmc_vec3_ortho)
 TEST_DECLARE(glmc_vec3_clamp)
 TEST_DECLARE(glmc_vec3_mix)
 TEST_DECLARE(glmc_vec3_mixc)
-TEST_DECLARE(glmc_vec3_step_uni)
 TEST_DECLARE(glmc_vec3_step)
 TEST_DECLARE(glmc_vec3_smoothstep_uni)
 TEST_DECLARE(glmc_vec3_smoothstep)
@@ -763,6 +786,10 @@ TEST_DECLARE(glmc_vec3_isvalid)
 TEST_DECLARE(glmc_vec3_sign)
 TEST_DECLARE(glmc_vec3_abs)
 TEST_DECLARE(glmc_vec3_fract)
+TEST_DECLARE(glmc_vec3_floor)
+TEST_DECLARE(glmc_vec3_mods)
+TEST_DECLARE(glmc_vec3_steps)
+TEST_DECLARE(glmc_vec3_stepr)
 TEST_DECLARE(glmc_vec3_hadd)
 TEST_DECLARE(glmc_vec3_sqrt)
 TEST_DECLARE(glmc_vec3_make)
@@ -831,7 +858,6 @@ TEST_DECLARE(glm_vec4_lerp)
 TEST_DECLARE(glm_vec4_lerpc)
 TEST_DECLARE(glm_vec4_mix)
 TEST_DECLARE(glm_vec4_mixc)
-TEST_DECLARE(glm_vec4_step_uni)
 TEST_DECLARE(glm_vec4_step)
 TEST_DECLARE(glm_vec4_smoothstep_uni)
 TEST_DECLARE(glm_vec4_smoothstep)
@@ -854,6 +880,10 @@ TEST_DECLARE(glm_vec4_isvalid)
 TEST_DECLARE(glm_vec4_sign)
 TEST_DECLARE(glm_vec4_abs)
 TEST_DECLARE(glm_vec4_fract)
+TEST_DECLARE(glm_vec4_floor)
+TEST_DECLARE(glm_vec4_mods)
+TEST_DECLARE(glm_vec4_steps)
+TEST_DECLARE(glm_vec4_stepr)
 TEST_DECLARE(glm_vec4_hadd)
 TEST_DECLARE(glm_vec4_sqrt)
 TEST_DECLARE(glm_vec4_make)
@@ -905,7 +935,6 @@ TEST_DECLARE(glmc_vec4_lerp)
 TEST_DECLARE(glmc_vec4_lerpc)
 TEST_DECLARE(glmc_vec4_mix)
 TEST_DECLARE(glmc_vec4_mixc)
-TEST_DECLARE(glmc_vec4_step_uni)
 TEST_DECLARE(glmc_vec4_step)
 TEST_DECLARE(glmc_vec4_smoothstep_uni)
 TEST_DECLARE(glmc_vec4_smoothstep)
@@ -928,6 +957,10 @@ TEST_DECLARE(glmc_vec4_isvalid)
 TEST_DECLARE(glmc_vec4_sign)
 TEST_DECLARE(glmc_vec4_abs)
 TEST_DECLARE(glmc_vec4_fract)
+TEST_DECLARE(glmc_vec4_floor)
+TEST_DECLARE(glmc_vec4_mods)
+TEST_DECLARE(glmc_vec4_steps)
+TEST_DECLARE(glmc_vec4_stepr)
 TEST_DECLARE(glmc_vec4_hadd)
 TEST_DECLARE(glmc_vec4_sqrt)
 TEST_DECLARE(glmc_vec4_make)
@@ -1274,6 +1307,9 @@ TEST_LIST {
   TEST_ENTRY(glmc_rotate2d_make)
   TEST_ENTRY(glmc_rotate2d)
   TEST_ENTRY(glmc_rotate2d_to)
+
+  /* aabb2d */
+  TEST_ENTRY(glm_aabb2d_sizev)
   
   /* mat4 */
   TEST_ENTRY(glm_mat4_ucopy)
@@ -1494,13 +1530,13 @@ TEST_LIST {
   TEST_ENTRY(glm_mat2x4_transpose)
   TEST_ENTRY(glm_mat2x4_scale)
 
-  TEST_ENTRY(glm_mat2x4_copy)
-  TEST_ENTRY(glm_mat2x4_zero)
-  TEST_ENTRY(glm_mat2x4_make)
-  TEST_ENTRY(glm_mat2x4_mul)
-  TEST_ENTRY(glm_mat2x4_mulv)
-  TEST_ENTRY(glm_mat2x4_transpose)
-  TEST_ENTRY(glm_mat2x4_scale)
+  TEST_ENTRY(glmc_mat2x4_copy)
+  TEST_ENTRY(glmc_mat2x4_zero)
+  TEST_ENTRY(glmc_mat2x4_make)
+  TEST_ENTRY(glmc_mat2x4_mul)
+  TEST_ENTRY(glmc_mat2x4_mulv)
+  TEST_ENTRY(glmc_mat2x4_transpose)
+  TEST_ENTRY(glmc_mat2x4_scale)
 
   /* camera (incl [LR]H cross [NZ]O) */
   TEST_ENTRY(glm_perspective_lh_zo)
@@ -1533,6 +1569,14 @@ TEST_LIST {
   /* plane */
   TEST_ENTRY(glm_plane_normalize)
   TEST_ENTRY(glmc_plane_normalize)
+
+  /* noise */
+  TEST_ENTRY(glm_perlin_vec4)
+  TEST_ENTRY(glmc_perlin_vec4)
+  TEST_ENTRY(glm_perlin_vec3)
+  TEST_ENTRY(glmc_perlin_vec3)
+  TEST_ENTRY(glm_perlin_vec2)
+  TEST_ENTRY(glmc_perlin_vec2)
   
   /* utils */
   TEST_ENTRY(clamp)
@@ -1708,6 +1752,12 @@ TEST_LIST {
   TEST_ENTRY(glm_vec2_maxv)
   TEST_ENTRY(glm_vec2_minv)
   TEST_ENTRY(glm_vec2_clamp)
+  TEST_ENTRY(glm_vec2_abs)
+  TEST_ENTRY(glm_vec2_fract)
+  TEST_ENTRY(glm_vec2_floor)
+  TEST_ENTRY(glm_vec2_mods)
+  TEST_ENTRY(glm_vec2_steps)
+  TEST_ENTRY(glm_vec2_stepr)
   TEST_ENTRY(glm_vec2_lerp)
   TEST_ENTRY(glm_vec2_complex_mul)
   TEST_ENTRY(glm_vec2_complex_div)
@@ -1756,6 +1806,11 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec2_minv)
   TEST_ENTRY(glmc_vec2_clamp)
   TEST_ENTRY(glmc_vec2_abs)
+  TEST_ENTRY(glmc_vec2_fract)
+  TEST_ENTRY(glmc_vec2_floor)
+  TEST_ENTRY(glmc_vec2_mods)
+  TEST_ENTRY(glmc_vec2_steps)
+  TEST_ENTRY(glmc_vec2_stepr)
   TEST_ENTRY(glmc_vec2_lerp)
   TEST_ENTRY(glmc_vec2_complex_mul)
   TEST_ENTRY(glmc_vec2_complex_div)
@@ -1838,7 +1893,6 @@ TEST_LIST {
   TEST_ENTRY(glm_vec3_clamp)
   TEST_ENTRY(glm_vec3_mix)
   TEST_ENTRY(glm_vec3_mixc)
-  TEST_ENTRY(glm_vec3_step_uni)
   TEST_ENTRY(glm_vec3_step)
   TEST_ENTRY(glm_vec3_smoothstep_uni)
   TEST_ENTRY(glm_vec3_smoothstep)
@@ -1860,6 +1914,10 @@ TEST_LIST {
   TEST_ENTRY(glm_vec3_sign)
   TEST_ENTRY(glm_vec3_abs)
   TEST_ENTRY(glm_vec3_fract)
+  TEST_ENTRY(glm_vec3_floor)
+  TEST_ENTRY(glm_vec3_mods)
+  TEST_ENTRY(glm_vec3_steps)
+  TEST_ENTRY(glm_vec3_stepr)
   TEST_ENTRY(glm_vec3_hadd)
   TEST_ENTRY(glm_vec3_sqrt)
   TEST_ENTRY(glm_vec3_make)
@@ -1917,7 +1975,6 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec3_clamp)
   TEST_ENTRY(glmc_vec3_mix)
   TEST_ENTRY(glmc_vec3_mixc)
-  TEST_ENTRY(glmc_vec3_step_uni)
   TEST_ENTRY(glmc_vec3_step)
   TEST_ENTRY(glmc_vec3_smoothstep_uni)
   TEST_ENTRY(glmc_vec3_smoothstep)
@@ -1939,6 +1996,10 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec3_sign)
   TEST_ENTRY(glmc_vec3_abs)
   TEST_ENTRY(glmc_vec3_fract)
+  TEST_ENTRY(glmc_vec3_floor)
+  TEST_ENTRY(glmc_vec3_mods)
+  TEST_ENTRY(glmc_vec3_steps)
+  TEST_ENTRY(glmc_vec3_stepr)
   TEST_ENTRY(glmc_vec3_hadd)
   TEST_ENTRY(glmc_vec3_sqrt)
   TEST_ENTRY(glmc_vec3_make)
@@ -2007,7 +2068,6 @@ TEST_LIST {
   TEST_ENTRY(glm_vec4_lerpc)
   TEST_ENTRY(glm_vec4_mix)
   TEST_ENTRY(glm_vec4_mixc)
-  TEST_ENTRY(glm_vec4_step_uni)
   TEST_ENTRY(glm_vec4_step)
   TEST_ENTRY(glm_vec4_smoothstep_uni)
   TEST_ENTRY(glm_vec4_smoothstep)
@@ -2030,6 +2090,10 @@ TEST_LIST {
   TEST_ENTRY(glm_vec4_sign)
   TEST_ENTRY(glm_vec4_abs)
   TEST_ENTRY(glm_vec4_fract)
+  TEST_ENTRY(glm_vec4_floor)
+  TEST_ENTRY(glm_vec4_mods)
+  TEST_ENTRY(glm_vec4_steps)
+  TEST_ENTRY(glm_vec4_stepr)
   TEST_ENTRY(glm_vec4_hadd)
   TEST_ENTRY(glm_vec4_sqrt)
   TEST_ENTRY(glm_vec4_make)
@@ -2081,7 +2145,6 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec4_lerpc)
   TEST_ENTRY(glmc_vec4_mix)
   TEST_ENTRY(glmc_vec4_mixc)
-  TEST_ENTRY(glmc_vec4_step_uni)
   TEST_ENTRY(glmc_vec4_step)
   TEST_ENTRY(glmc_vec4_smoothstep_uni)
   TEST_ENTRY(glmc_vec4_smoothstep)
@@ -2104,6 +2167,10 @@ TEST_LIST {
   TEST_ENTRY(glmc_vec4_sign)
   TEST_ENTRY(glmc_vec4_abs)
   TEST_ENTRY(glmc_vec4_fract)
+  TEST_ENTRY(glmc_vec4_floor)
+  TEST_ENTRY(glmc_vec4_mods)
+  TEST_ENTRY(glmc_vec4_steps)
+  TEST_ENTRY(glmc_vec4_stepr)
   TEST_ENTRY(glmc_vec4_hadd)
   TEST_ENTRY(glmc_vec4_sqrt)
   TEST_ENTRY(glmc_vec4_make)
